@@ -44,15 +44,15 @@ from sqlalchemy_tools.database_connector.database_connector import DatabaseConne
 from sqlalchemy_tools.entity_helpers.sqlalchemy_base import Values
 from dict_caster.extras import first, to_list
 
-from entity_view.viewable_entity import ViewableEntity, SelectedView, get_related_entity_type, get_remote_column, \
+from .entity_view.viewable_entity import ViewableEntity, SelectedView, get_related_entity_type, get_remote_column, \
     get_column_pairs_from_relation, DeleteView, DeltaView, InsertView
-from entity_view.layers.select_atoms import ERoot
-from entity_view.layers.select_middle import e_root_to_sql
+from .entity_view.layers.select_atoms import ERoot
+from .entity_view.layers.select_middle import e_root_to_sql
 from extended_logger import get_logger
-from entity_field import NoDefault
+from .entity_field import NoDefault
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
-from utils import split_by_type
+from .utils import split_by_type
 
 logger = get_logger(__name__)
 T = TypeVar('T', bound=ViewableEntity)
